@@ -1,5 +1,5 @@
 ##***********************************************************************
-## $Id: runit.utils.R 19 2010-08-06 15:06:01Z mariotomo $
+## $Id: runit.utils.R 28 2010-08-11 12:15:43Z mariotomo $
 ##
 ## this file is part of the R library delftfews.  delftfews is free
 ## software: you can redistribute it and/or modify it under the terms
@@ -169,13 +169,15 @@ test.stretches.NA.long.gap.gross.not.surrounded <- function() {
   checkEquals(c(2),       stretches(input, gap=4, zero.surrounded=TRUE))
 }
 
-test.rollingSum <- function(){
+test.rollingSum.base <- function() {
   input <- (1:20)
   result <- rollingSum(input, 10)
   expect <- c(NA, NA, NA, NA, NA,  NA,  NA,  NA,  NA,  55,  65,  75,  85,  95, 105, 115, 125, 135, 145, 155)
   checkEquals(length(expect), length(result))
   checkEquals(expect, result)
-  
+}
+
+test.rollingSum.with.na <- function() {  
   input <- c(1, 1, 1, NA, 2, 2, 1, NA, 1, 2, 1)
   result <- rollingSum(input, 3)
   expect <- c(NA, NA, 3, 2, 3, 4, 5, 3, 2, 3, 4)
@@ -183,6 +185,16 @@ test.rollingSum <- function(){
   checkEquals(expect, result)
 }
 
+test.rollingSum.delftfews <- function() {
+  input <- timeseries(from=0, by=720*60, length.out=20, a=1, b=1:20)
+  result <- rollingSum(input$b, 10)
+  target.numeric <- c(NA, NA, NA, NA, NA,  NA,  NA,  NA,  NA,  55,  65,  75,  85,  95, 105, 115, 125, 135, 145, 155)
+  checkEquals(length(target.numeric), length(result))
+  checkEqualsNumeric(target.numeric, result)
+  target <- timeseries(from=0, by=720*60, length.out=20, b=target.numeric)
+  checkEquals(target, result)
+}
+
 test.rollapply <- function() {
   input <- c(rep(1:3, 2), NA, 4, 4, 4)
   ##  [1]  1  2  3  1  2  3 NA  4  4  4
